package cn.com.ty.lift.business.emergency.controller;


import cn.com.ty.lift.business.emergency.dto.LiftFaultCategory;
import cn.com.ty.lift.business.emergency.dto.LiftFaultType;
import cn.com.ty.lift.business.emergency.dto.RepairRequest;
import cn.com.ty.lift.business.emergency.entity.LiftFault;
import cn.com.ty.lift.business.emergency.service.LiftFaultService;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 *  电梯急修故障类型 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2020-01-02
 */
@Slf4j
@AllArgsConstructor
@RestController
@RequestMapping("/emergency/lift-fault")
public class LiftFaultController {

    private LiftFaultService liftFaultService;

    @PostMapping("list")
    public RestResponse list(@RequestBody RepairRequest request){
        Integer liftCategory = request.getLiftCategory();
        if(null == liftCategory || liftCategory < 0){
            return RestResponse.success(liftFaultService.list());
        }
        List<LiftFault> lists = liftFaultService.listByLiftCategory(liftCategory);

        return RestResponse.success(lists);
    }



    @PostMapping("tree")
    public RestResponse tree(@RequestBody RepairRequest request) {
        Integer liftCategory = request.getLiftCategory();
        if(null == liftCategory || liftCategory < 0){
            List<LiftFault> liftFaults = liftFaultService.list();
            return assemble(liftFaults);
        }else{
            List<LiftFault> liftFaults = liftFaultService.listByLiftCategory(liftCategory);
            return assemble(liftFaults);
        }
    }

    /**
     * 根据故障列表组装tree
     * @param liftFaults
     * @return
     */
    private RestResponse assemble(List<LiftFault> liftFaults){
        if (ObjectUtil.isEmpty(liftFaults)) {
            return RestResponse.fail("没有故障信息");
        }

        List<String> categories = liftFaults.stream().map(LiftFault::getFaultCategory).distinct().collect(Collectors.toList());
        if (ObjectUtil.isEmpty(categories)) {
            return RestResponse.fail("没有故障类型");
        }
        List<LiftFaultCategory> liftFaultCategories = new ArrayList<>();
        categories.forEach(category -> {
            log.info("category: {}", category);
            List<String> types = liftFaults.stream().filter(liftFault -> (
                    StrUtil.equals(category,liftFault.getFaultCategory())
            )).map(LiftFault::getFaultType).distinct().collect(Collectors.toList());
            log.info("types: {}", types);
            List<LiftFaultType> liftFaultTypes = new ArrayList<>();
            if (ObjectUtil.isNotEmpty(types)) {
                types.forEach(type -> {
                    log.info("type: {}",type);
                    List<LiftFault> faults = liftFaults.stream().filter(liftFault -> (
                            StrUtil.equals(category, liftFault.getFaultCategory()) &&
                                    StrUtil.equals(type, liftFault.getFaultType())
                    )).distinct().collect(Collectors.toList());
                    liftFaultTypes.add(new LiftFaultType(type,faults));
                });
            }
            liftFaultCategories.add(new LiftFaultCategory(category,liftFaultTypes));
        });
        return RestResponse.success(liftFaultCategories);
    }
}
