package cn.com.ty.lift.system.banner.service.impl;

import cn.com.ty.lift.common.utils.AliyunOSSUtil;
import cn.com.ty.lift.system.banner.dao.entity.BannerImage;
import cn.com.ty.lift.system.banner.dao.mapper.BannerImageMapper;
import cn.com.ty.lift.system.banner.service.BannerImageService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * <p>
 * banner图管理 服务实现类
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-31
 */
@Service
public class BannerImageServiceImpl extends ServiceImpl<BannerImageMapper, BannerImage> implements BannerImageService {

    public RestResponse upFile(MultipartFile file) {
        String originalFilename = file.getOriginalFilename();
        if (originalFilename != null && originalFilename.contains(".")) {
            String fileName = "banner/image/" + IdWorker.getIdStr()
                    + "."
                    + originalFilename.substring(file.getOriginalFilename().lastIndexOf(".") + 1);
            //阿里云OSS操作结果
            boolean result = false;
            try {
                result = new AliyunOSSUtil().putObject(file.getBytes(), fileName);
            } catch (IOException e) {
                e.printStackTrace();
            }
            if (result) {
                return RestResponse.success(fileName);
            }
            return RestResponse.fail();
        }
        return RestResponse.failParam();
    }

    public RestResponse modify(BannerImage bannerImage) {
        BannerImage byId = this.getById(bannerImage);
        if (byId.getImageName() != null) {
            AliyunOSSUtil.me().deleteObject(byId.getImageName());
        }
        if (this.saveOrUpdate(bannerImage)) {
            return RestResponse.success(bannerImage.getId(), "成功");
        }
        return RestResponse.fail();
    }

    public RestResponse delete(BannerImage bannerImage) {
        BannerImage byId = this.getById(bannerImage);
        if (byId.getImageName() != null) {
            AliyunOSSUtil.me().deleteObject(byId.getImageName());
        }
        if (this.removeById(bannerImage)) {
            return RestResponse.success(null, "成功");
        }
        return RestResponse.fail();
    }

    public RestResponse banners(BannerImage banner) {
        List<BannerImage> banners = this.list(new QueryWrapper<BannerImage>()
                .eq(banner.getType() != null, "type", banner.getType())
                .orderByAsc("serial_no"));
        if (banners.isEmpty()) {
            return RestResponse.success();
        }
        for (BannerImage bannerImage : banners) {
            bannerImage.setImageName("https://temp15827479607.oss-cn-beijing.aliyuncs.com/" + bannerImage.getImageName());
        }
        return RestResponse.success(banners);
    }
}
